@@ -223,6 +223,25 @@ class TestCase(unittest.TestCase):
         self.assertRaises(ValueError, list, toposort(data))
         self.assertEqual(data, orig)
 
+    def test_unsortable_with_circular_dependency(self):
+        # https://gitlab.com/ericvsmith/toposort/-/issues/2
+
+        # Objects which are hashable, but not orderable should not raise a
+        # typeError when raising a CircularDependencyError.
+        class A: pass
+
+        class B: pass
+
+        class C: pass
+
+        # These work okay.
+        self.assertEqual(list(toposort({A: {B}, B: {C}})), [{C}, {B}, {A}])
+        self.assertEqual(list(toposort({A: set(), B: set(), C: set()})), [{A, B, C}])
+
+        # This used to raise a TypeError, because of the sorting when
+        # CircularDependencyError was raised.
+        self.assertRaises(CircularDependencyError, list, toposort({A: {B}, B: {C}, C: {A}}))
+
 
 class TestCaseAll(unittest.TestCase):
     def test_sort_flatten(self):
